@@ -1,4 +1,5 @@
 import pathlib
+import sys
 from typing import (
     TYPE_CHECKING, Any, Collection, Dict, List, NamedTuple, Optional, Set,
     Tuple, Union,
@@ -10,11 +11,18 @@ else:
     import dataclasses
     from pydantic.dataclasses import dataclass
 
-
+# All files in Square have this type.
 Filepath = pathlib.Path
 
+# Determine the base folder. This is usually the folder of this very file, but
+# will be different if we run inside a bundle produced by PyInstaller.
+if getattr(sys, '_MEIPASS', None):
+    BASE_DIR = Filepath(getattr(sys, '_MEIPASS'))
+else:
+    BASE_DIR = Filepath(__file__).parent.parent
+
 # Square will source all its default values from this configuration file.
-DEFAULT_CONFIG_FILE = Filepath(__file__).parent.parent / "resources/defaultconfig.yaml"
+DEFAULT_CONFIG_FILE = BASE_DIR / "resources/defaultconfig.yaml"
 
 # Square will first save/deploy the resources in this list in this order.
 # Afterwards it will move on to all those resources not in this list. The order
@@ -101,8 +109,8 @@ class K8sConfig(NamedTuple):
     short2kind: Dict[str, str] = {}
 
     # The set of supported K8s resource kinds, eg {"Deployment", "Service"}.
-    # NOTE: these are the `manifest.kind` spellings. "Deployment" is a kind
-    # whereas "deployment" or "Deployments" are not.
+    # NOTE: these are the `manifest.kind` spellings. "Deployment" is a valid
+    # K8s resource kind, whereas "deployment" or "Deployments" are not.
     kinds: Set[str] = set()
 
 
@@ -167,7 +175,7 @@ class Selectors:
     """Comprises all the filters to select manifests."""
     kinds: Set[str] = _factory(set(DEFAULT_PRIORITIES))
     namespaces: List[str] = _factory([])
-    labels: Set[Tuple[str, str]] = _factory(set())
+    labels: List[str] = _factory([])
 
 
 @dataclass
