@@ -1,7 +1,6 @@
 import argparse
 import logging
 import os
-import re
 from typing import Optional, Tuple
 
 import colorama
@@ -18,12 +17,11 @@ logit = logging.getLogger("square")
 
 def parse_commandline_args():
     """Return parsed command line."""
-    def _validate_label(label: str) -> Tuple[str, ...]:
-        """Unpack the labels: "app=square" -> ("app", "square") """
-        pat = re.compile(r"^[a-z0-9][-a-z0-9_.]*=[-A-Za-z0-9_.]*[A-Za-z0-9]$")
-        if pat.match(label) is None:
+    def _validate_label(label: str) -> str:
+        """Sanity check the label"""
+        if not square.square.valid_label(label):
             raise argparse.ArgumentTypeError(label)
-        return tuple(label.split("="))
+        return label
 
     # A dummy top level parser that will become the parent for all sub-parsers
     # to share all its arguments.
@@ -171,7 +169,7 @@ def compile_config(cmdline_param) -> Tuple[Config, bool]:
         folder=Filepath(""),
         kubeconfig=Filepath(""),
         kubecontext=None,
-        selectors=Selectors(set(), namespaces=[], labels=set()),
+        selectors=Selectors(set(), namespaces=[], labels=[]),
         groupby=GroupBy("", []),
         priorities=[],
     ), True
@@ -207,7 +205,7 @@ def compile_config(cmdline_param) -> Tuple[Config, bool]:
         if cfg_file == default_cfg:
             kubeconfig = p.kubeconfig or os.getenv("KUBECONFIG", "")
         else:
-            kubeconfig = p.kubeconfig or str(cfg.kubeconfig) or os.getenv("KUBECONFIG", "")
+            kubeconfig = p.kubeconfig or str(cfg.kubeconfig) or os.getenv("KUBECONFIG", "")  # noqa
         del dot_square, default_cfg
 
         # Use the current working directory as the folder directory because the
@@ -277,7 +275,7 @@ def compile_config(cmdline_param) -> Tuple[Config, bool]:
     kubeconfig = Filepath(kubeconfig)
     kubecontext = p.kubecontext or cfg.kubecontext
     namespaces = cfg.selectors.namespaces if p.namespaces is None else p.namespaces
-    sel_labels = cfg.selectors.labels if p.labels is None else set(p.labels)
+    sel_labels = cfg.selectors.labels if p.labels is None else p.labels
     priorities = p.priorities or cfg.priorities
     selectors = Selectors(kinds, namespaces, sel_labels)
 
@@ -350,24 +348,26 @@ def apply_plan(cfg: Config, confirm_string: Optional[str]) -> bool:
     return False
 
 
-def sanitise_resource_kinds(cfg: Config) -> Tuple[Config, bool]:
-    """Populate the `Selector.kinds` with those the user specified on the commandline."""
+def expand_all_kinds(cfg: Config) -> Tuple[Config, bool]:
+    """Replace an empty `cfg.selector.kinds` with all available resources.
+
+    Does nothing if `cfg.selectors.kinds` is non-empty.
+
+    """
+    # Do nothing if the user specified at least on resource type.
+    if len(cfg.selectors.kinds) > 0:
+        return cfg, False
+
     # Create a K8sConfig instance because it will contain all the info we need.
     k8sconfig, err = square.k8s.cluster_config(cfg.kubeconfig, cfg.kubecontext)
     if err:
         return (cfg, True)
 
-    # Translate colloquial names to their canonical counterpart if possible.
-    # Example: "svc" -> "Service"
-    # Do nothing if we do not recognise the name. This can happen because the
-    # user made a typo, or the resource is a custom resource that is not yet
-    # known. Since we cannot distinguish them, we allow typos and then ignore
-    # the resource during the get/plan/apply cycle.
-    kinds = {k8sconfig.short2kind.get(_.lower(), _) for _ in cfg.selectors.kinds}
-
-    # Replace the (possibly) colloquial names with their correct K8s kinds.
+    # Replace the empty resource list with all kinds that K8s has to offer and
+    # that Square can manage (ie all kinds with the correct set of verbs to
+    # create, delete, get, and patch).
     cfg.selectors.kinds.clear()
-    cfg.selectors.kinds.update(kinds)
+    cfg.selectors.kinds.update(k8sconfig.kinds)
     return (cfg, False)
 
 
@@ -386,12 +386,15 @@ def show_info(cfg: Config) -> bool:
 
 def main() -> int:
     param = parse_commandline_args()
+
+    # Print version information and quit.
     if param.parser == "version":
         print(__version__)
         return 0
 
+    # Create a default ".square.yaml" in the current folder and quit.
     if param.parser == "config":
-        fname = Filepath(param.folder) / ".square.yaml"
+        fname = Filepath(param.folder or ".") / ".square.yaml"
         fname.parent.mkdir(parents=True, exist_ok=True)
         fname.write_text(DEFAULT_CONFIG_FILE.read_text())
         print(
@@ -406,7 +409,7 @@ def main() -> int:
 
     # Create Square configuration from command line arguments.
     cfg, err1 = compile_config(param)
-    cfg, err2 = sanitise_resource_kinds(cfg)
+    cfg, err2 = expand_all_kinds(cfg)
     if err1 or err2:
         return 1
 
